/***************************************************
//Web: http://www.buydisplay.com
EastRising Technology Co.,LTD
****************************************************/

#include "ER-EPD0583A1-1B.h"
#include "Debug.h"

/******************************************************************************
function :	Software reset
parameter:
******************************************************************************/
static void EPD_0583_1_Reset(void)
{
    DEV_Digital_Write(EPD_RST_PIN, 1);
    DEV_Delay_ms(200);
    DEV_Digital_Write(EPD_RST_PIN, 0);
    DEV_Delay_ms(10);
    DEV_Digital_Write(EPD_RST_PIN, 1);
    DEV_Delay_ms(200);
}

/******************************************************************************
function :	send command
parameter:
     Reg : Command register
******************************************************************************/
static void EPD_0583_1_SendCommand(UBYTE Reg)
{
    DEV_Digital_Write(EPD_DC_PIN, 0);
    DEV_Digital_Write(EPD_CS_PIN, 0);
    DEV_SPI_WriteByte(Reg);
    DEV_Digital_Write(EPD_CS_PIN, 1);
}

/******************************************************************************
function :	send data
parameter:
    Data : Write data
******************************************************************************/
static void EPD_0583_1_SendData(UBYTE Data)
{ 
    DEV_Digital_Write(EPD_CS_PIN, 0);
    DEV_Digital_Write(EPD_DC_PIN, 1);
    DEV_SPI_WriteByte(Data);
    DEV_Digital_Write(EPD_CS_PIN, 1);
}

/******************************************************************************
function :	Wait until the busy_pin goes LOW
parameter:
******************************************************************************/
void EPD_0583_1_WaitUntilIdle(void)
{
    Debug("e-Paper busy\r\n");
    while(DEV_Digital_Read(EPD_BUSY_PIN)==0){
        DEV_Delay_ms(10);
    }
    DEV_Delay_ms(200);      
    Debug("e-Paper busy release\r\n");
}

/******************************************************************************
function :	Turn On Display
parameter:
******************************************************************************/
static void EPD_0583_1_TurnOnDisplay(void)
{

   EPD_0583_1_SendCommand(0xE0); 
    EPD_0583_1_SendData(0X02);
    
    EPD_0583_1_SendCommand(0xE5);  
    EPD_0583_1_SendData(0x5C);
 
  

    EPD_0583_1_SendCommand(0x12);
    DEV_Delay_ms(100);        
    EPD_0583_1_WaitUntilIdle();       //waiting for the electronic paper IC to release the idle signal

}

/******************************************************************************
function :	Initialize the e-Paper register
parameter:
******************************************************************************/
UBYTE EPD_0583_1_Init(void)
{
     EPD_0583_1_Reset();

      EPD_0583_1_WaitUntilIdle();       

        EPD_0583_1_SendCommand(0x00);
        EPD_0583_1_SendData(0x1F);	 //BW  mode
        EPD_0583_1_SendData(0x0E);
		   
       EPD_0583_1_SendCommand(0x50);
        EPD_0583_1_SendData(0x83); 
	  EPD_0583_1_SendData(0x07);  

        EPD_0583_1_SendCommand(0x04); // Power ON 
        EPD_0583_1_WaitUntilIdle();       


    return 0;
}

/******************************************************************************
function :	Clear screen
parameter:
******************************************************************************/
void EPD_0583_1_Clear(void)
{
 UWORD Width, Height;
    Width =(EPD_0583_1_WIDTH % 8 == 0)?(EPD_0583_1_WIDTH / 8 ):(EPD_0583_1_WIDTH / 8 + 1);
    Height = EPD_0583_1_HEIGHT;

    UWORD i;
 /*   EPD_0583_1_SendCommand(0x10);
    for(i=0; i<Width*Height; i++) {
        EPD_0583_1_SendData(0xff);

    }*/

    EPD_0583_1_SendCommand(0x13);
    for(i=0; i<Width*Height; i++)	{
        EPD_0583_1_SendData(0xFF);

    }
    EPD_0583_1_TurnOnDisplay();


}




/******************************************************************************
function :	Sends the image buffer in RAM to e-Paper and displays
parameter:
******************************************************************************/
void EPD_0583_1_Display(const UBYTE *blackimage)
{
     UDOUBLE Width, Height,j,i;
    Width =(EPD_0583_1_WIDTH % 8 == 0)?(EPD_0583_1_WIDTH / 8 ):(EPD_0583_1_WIDTH / 8 + 1);
    Height = EPD_0583_1_HEIGHT;
  
/* //send black data
    EPD_0583_1_SendCommand(0x10);
    for ( j = 0; j < Height; j++) {
        for ( i = 0; i < Width; i++) {
            EPD_0583_1_SendData(0xFF);
        }
    }*/
 

    //send red data
    EPD_0583_1_SendCommand(0x13);
    for ( j = 0; j < Height; j++) {
        for ( i = 0; i < Width; i++) {
            EPD_0583_1_SendData(blackimage[i + j * Width]);
        }
    }

    EPD_0583_1_TurnOnDisplay();
}



/******************************************************************************
function :	Enter sleep mode
parameter:
******************************************************************************/
void EPD_0583_1_Sleep(void)
{
    EPD_0583_1_SendCommand(0x02); // POWER OFF
    EPD_0583_1_WaitUntilIdle();

    EPD_0583_1_SendCommand(0x07);  	//deep sleep
    EPD_0583_1_SendData(0xA5);

}
